use std::path::Path;

use anyhow::{Context, Result};
use freva::drs::Config as DrsConfig;
use log::debug;
use serde::Deserialize;

#[derive(Debug, Deserialize)]
pub struct Config {
    pub solr: SolrConfig,
}

#[derive(Debug, Deserialize)]
pub struct SolrConfig {
    pub host: String,
    pub port: Option<u16>,
    pub core: String,
}

const CONFIG_NAME: &str = "freva.toml";
const DRS_CONFIG_NAME: &str = "drs_config.toml";

pub fn config<P: AsRef<Path>>(config_dir: P) -> Result<Config> {
    let config_file = config_dir.as_ref().join(CONFIG_NAME);
    debug!("loading freva config from {}", config_file.display());
    let data = std::fs::read_to_string(&config_file)
        .with_context(|| format!("error reading config file {}", config_file.display()))?;
    toml::from_str(&data).context("parsing freva config")
}

pub fn drs_config<P: AsRef<Path>>(config_dir: P) -> Result<DrsConfig> {
    let config_file = config_dir.as_ref().join(DRS_CONFIG_NAME);
    debug!("loading drs config from {}", config_file.display());
    DrsConfig::from_toml(&config_file)
        .with_context(|| format!("error reading config file {:?}", config_file))
}
