mod cli;
mod config;
mod solr;

use anyhow::{Context, Result};
use clap::StructOpt;
use cli::Cli;
use config::{config, drs_config};
use directories::ProjectDirs;

#[tokio::main]
async fn main() -> Result<()> {
    let args = Cli::try_parse()?;

    let verbosity = if args.debug {
        3 // debug
    } else {
        1 // warning
    };

    stderrlog::new()
        .module(module_path!())
        .verbosity(verbosity)
        .init()?;

    let config_dir = match args.config_dir {
        Some(c) => c,
        None => ProjectDirs::from("de", "DKRZ", "freva")
            .context("no config dir given and no valid home directory found")?
            .config_dir()
            .to_owned(),
    };

    let conf = config(&config_dir)?;
    let drs_conf = drs_config(&config_dir)?;
    let ingest_opts = args.opts;

    solr::ingest(&ingest_opts, &conf, &drs_conf).await
}
